@@ -106,6 +106,16 @@ class StaticCompoundInfo(HKBaseClass):
 
         return inst
 
+    def __eq__(self, value):
+        if not isinstance(value, StaticCompoundInfo):
+            raise NotImplementedError()
+        return hash(self) == hash(value)
+
+    def __hash__(self):
+        return hash(
+            frozenset([frozenset(value) for value in (self.ActorInfo, self.ShapeInfo)])
+        )
+
     def __repr__(self):
         return (
             f"{self.__class__.__name__}({len(self.ActorInfo)}, {len(self.ShapeInfo)})"
