@@ -1,20 +1,21 @@
+from collections.abc import Iterable
+
 from ..binary import BinaryReader, BinaryWriter
-from ..binary.types import String
-from ..container.util.hkobject import HKObject
 
 if False:
     from ..hkfile import HKFile
+    from ..container.util.hkobject import HKObject
 
 
 class HKBaseClass:
-    hkClass: String
+    hkClass: str
 
-    def deserialize(self, hkFile: "HKFile", br: BinaryReader, obj: HKObject):
+    def deserialize(self, hkFile: "HKFile", br: BinaryReader, obj: "HKObject"):
         # SPECIFIC HKCLASS BEHAVIOUR EXECUTES AFTER THIS
 
         self.hkClass = obj.hkClass.name
 
-    def serialize(self, hkFile: "HKFile", bw: BinaryWriter, obj: HKObject):
+    def serialize(self, hkFile: "HKFile", bw: BinaryWriter, obj: "HKObject"):
         # SPECIFIC HKCLASS BEHAVIOUR EXECUTES BEFORE THIS
 
         obj.bytes = bw.getvalue()
@@ -29,14 +30,21 @@ class HKBaseClass:
     @classmethod
     def from_dict(cls, d: dict):
         inst = cls()
-        inst.hkClass = String(d["hkClass"])
+        inst.hkClass = d["hkClass"]
 
         return inst
 
     def __eq__(self, value: object):
         if not isinstance(value, HKBaseClass):
             raise NotImplementedError()
-        comparison = self.__dict__ == value.__dict__
-        if not comparison:
-            print(f"Class '{self.__class__.__name__}' doesn't match")
-        return comparison
+        return hash(self) == hash(value)
+
+    def __hash__(self):
+        return hash(
+            frozenset(
+                [
+                    value if not isinstance(value, Iterable) else frozenset(value)
+                    for value in self.__dict__.values()
+                ]
+            )
+        )
