@@ -1,4 +1,5 @@
 import argparse
+
 from .. import Havok
 from .common import Fore, Messages, change_extension, check_if_exists, init
 
@@ -8,14 +9,14 @@ def parse_args():
         description="Compare Havok packfiles.\nAlso works between Wii U and Switch packfiles."
     )
     parser.add_argument(
-        "hkFiles", help="Paths to Havok packfiles for comparison", nargs="++"
+        "hkFiles", help="Paths to Havok packfiles for comparison", nargs="+"
     )
 
     return parser.parse_args()
 
 
 def main():
-    init()
+    init(autoreset=True)
 
     args = parse_args()
 
@@ -38,8 +39,8 @@ def main():
             if file0.data.contents[0] != file1.data.contents[0]:
                 print(f"{Fore.RED}File contents don't match")
                 break
-    else:
-        print(f"{Fore.GREEN}File contents match")
+        else:
+            print(f"{Fore.GREEN}File contents match")
 
     Messages.done()
 
